Index: uspace/lib/c/include/ipc/loc.h
===================================================================
--- uspace/lib/c/include/ipc/loc.h	(revision 1dc4a5e441cc195a33bd958ea4994dcd59141df0)
+++ uspace/lib/c/include/ipc/loc.h	(revision 763e0cddf0e1c4057130bf42fd3ecf4c6658bc63)
@@ -59,4 +59,5 @@
 	LOC_CALLBACK_CREATE,
 	LOC_CATEGORY_GET_ID,
+	LOC_CATEGORY_GET_NAME,
 	LOC_CATEGORY_GET_SVCS,
 	LOC_ID_PROBE,

Index: uspace/lib/c/generic/loc.c
===================================================================
--- uspace/lib/c/generic/loc.c	(revision 1dc4a5e441cc195a33bd958ea4994dcd59141df0)
+++ uspace/lib/c/generic/loc.c	(revision 763e0cddf0e1c4057130bf42fd3ecf4c6658bc63)
@@ -364,14 +364,15 @@
 }
 
 /** Get service name.
  *
  * Provided ID of a service, return its name.
  *
  * @param svc_id	Service ID
  * @param name		Place to store pointer to new string. Caller should
  *			free it using free().
  * @return		EOK on success or negative error code
  */
-int loc_service_get_name(service_id_t svc_id, char **name)
+static int loc_get_name_internal(sysarg_t method, sysarg_t id, char **name)
 {
 	async_exch_t *exch;
@@ -385,5 +386,5 @@
 	
 	ipc_call_t answer;
-	aid_t req = async_send_1(exch, LOC_SERVICE_GET_NAME, svc_id, &answer);
+	aid_t req = async_send_1(exch, method, id, &answer);
 	aid_t dreq = async_data_read(exch, name_buf, LOC_NAME_MAXLEN,
 	    &dreply);
@@ -414,4 +415,31 @@
 }
 
+/** Get category name.
+ *
+ * Provided ID of a service, return its name.
+ *
+ * @param cat_id	Category ID
+ * @param name		Place to store pointer to new string. Caller should
+ *			free it using free().
+ * @return		EOK on success or negative error code
+ */
+int loc_category_get_name(category_id_t cat_id, char **name)
+{
+	return loc_get_name_internal(LOC_CATEGORY_GET_NAME, cat_id, name);
+}
+
+/** Get service name.
+ *
+ * Provided ID of a service, return its name.
+ *
+ * @param svc_id	Service ID
+ * @param name		Place to store pointer to new string. Caller should
+ *			free it using free().
+ * @return		EOK on success or negative error code
+ */
+int loc_service_get_name(service_id_t svc_id, char **name)
+{
+	return loc_get_name_internal(LOC_SERVICE_GET_NAME, svc_id, name);
+}
 
 int loc_namespace_get_id(const char *name, service_id_t *handle,
@@ -364,14 +364,15 @@
 }
 
-/** Get service name.
- *
- * Provided ID of a service, return its name.
- *
- * @param svc_id	Service ID
+/** Get object name.
+ *
+ * Provided ID of an object, return its name.
+ *
+ * @param method	IPC method
+ * @param id		Object ID
  * @param name		Place to store pointer to new string. Caller should
  *			free it using free().